@@ -31,7 +31,8 @@ parser = sys.modules[__name__]
 parser.dep = sys.modules[__name__]
 parser.typdep = sys.modules[__name__]
 embeddings = sys.modules[__name__]
-
+classifier = sys.modules[__name__]
+classifier.dl = sys.modules[__name__]
 
 try:
     import jsl_sparknlp.annotator
@@ -84,6 +85,11 @@ class Tokenizer(AnnotatorApproach):
                          "character list used to separate from token boundaries",
                          typeConverter=TypeConverters.toListString)
 
+    splitPattern = Param(Params._dummy(),
+                         "splitPattern",
+                         "character list used to separate from the inside of tokens",
+                         typeConverter=TypeConverters.toString)
+
     splitChars = Param(Params._dummy(),
                        "splitChars",
                        "character list used to separate from the inside of tokens",
@@ -178,6 +184,9 @@ class Tokenizer(AnnotatorApproach):
         context_chars.append(value)
         return self._set(contextChars=context_chars)
 
+    def setSplitPattern(self, value):
+        return self._set(splitPattern=value)
+
     def setSplitChars(self, value):
         return self._set(splitChars=value)
 
@@ -222,6 +231,11 @@ class TokenizerModel(AnnotatorModel):
                   "Rules structure factory containing pre processed regex rules",
                   typeConverter=TypeConverters.identity)
 
+    splitPattern = Param(Params._dummy(),
+                         "splitPattern",
+                         "character list used to separate from the inside of tokens",
+                         typeConverter=TypeConverters.toString)
+
     splitChars = Param(Params._dummy(),
                        "splitChars",
                        "character list used to separate from the inside of tokens",
@@ -237,6 +251,9 @@ class TokenizerModel(AnnotatorModel):
             caseSensitiveExceptions=True
         )
 
+    def setSplitPattern(self, value):
+        return self._set(splitPattern=value)
+
     def setSplitChars(self, value):
         return self._set(splitChars=value)
 
@@ -601,9 +618,9 @@ class BigTextMatcher(AnnotatorApproach, HasStorage):
                              typeConverter=TypeConverters.toBoolean)
 
     tokenizer = Param(Params._dummy(),
-                          "tokenizer",
-                          "TokenizerModel to use to tokenize input file for building a Trie",
-                          typeConverter=TypeConverters.identity)
+                      "tokenizer",
+                      "TokenizerModel to use to tokenize input file for building a Trie",
+                      typeConverter=TypeConverters.identity)
 
     @keyword_only
     def __init__(self):
@@ -738,19 +755,19 @@ class SentenceDetectorParams:
                              typeConverter=TypeConverters.toBoolean)
 
     splitLength = Param(Params._dummy(),
-                      "splitLength",
-                      "length at which sentences will be forcibly split.",
-                      typeConverter=TypeConverters.toInt)
+                        "splitLength",
+                        "length at which sentences will be forcibly split.",
+                        typeConverter=TypeConverters.toInt)
 
     minLength = Param(Params._dummy(),
-                        "minLength",
-                        "Set the minimum allowed length for each sentence.",
-                        typeConverter=TypeConverters.toInt)
+                      "minLength",
+                      "Set the minimum allowed length for each sentence.",
+                      typeConverter=TypeConverters.toInt)
 
     maxLength = Param(Params._dummy(),
-                        "maxLength",
-                        "Set the maximum allowed length for each sentence",
-                        typeConverter=TypeConverters.toInt)
+                      "maxLength",
+                      "Set the maximum allowed length for each sentence",
+                      typeConverter=TypeConverters.toInt)
 
 
 class SentenceDetector(AnnotatorModel, SentenceDetectorParams):
@@ -1544,14 +1561,14 @@ class WordEmbeddings(AnnotatorApproach, HasEmbeddingsProperties, HasStorage):
     name = "WordEmbeddings"
 
     writeBufferSize = Param(Params._dummy(),
-                               "writeBufferSize",
-                               "buffer size limit before dumping to disk storage while writing",
-                               typeConverter=TypeConverters.toInt)
+                            "writeBufferSize",
+                            "buffer size limit before dumping to disk storage while writing",
+                            typeConverter=TypeConverters.toInt)
 
     readCacheSize = Param(Params._dummy(),
-                            "readCacheSize",
-                            "cache size for items retrieved from storage. Increase for performance but higher memory consumption",
-                            typeConverter=TypeConverters.toInt)
+                          "readCacheSize",
+                          "cache size for items retrieved from storage. Increase for performance but higher memory consumption",
+                          typeConverter=TypeConverters.toInt)
 
     def setWriteBufferSize(self, v):
         return self._set(writeBufferSize=v)
@@ -1686,7 +1703,7 @@ class BertEmbeddings(AnnotatorModel, HasEmbeddingsProperties, HasCaseSensitivePr
         return ResourceDownloader.downloadModel(BertEmbeddings, name, lang, remote_loc)
 
 
-class SentenceEmbeddings(AnnotatorModel):
+class SentenceEmbeddings(AnnotatorModel, HasEmbeddingsProperties, HasStorageRef):
 
     name = "SentenceEmbeddings"
 
@@ -1850,7 +1867,7 @@ class NerOverwriter(AnnotatorModel):
         return self._set(newResult=value)
 
 
-class UniversalSentenceEncoder(AnnotatorModel):
+class UniversalSentenceEncoder(AnnotatorModel, HasEmbeddingsProperties, HasStorageRef):
 
     name = "UniversalSentenceEncoder"
 
@@ -1940,3 +1957,99 @@ class ElmoEmbeddings(AnnotatorModel, HasEmbeddingsProperties, HasCaseSensitivePr
     def pretrained(name="elmo", lang="en", remote_loc=None):
         from sparknlp.pretrained import ResourceDownloader
         return ResourceDownloader.downloadModel(ElmoEmbeddings, name, lang, remote_loc)
+
+
+class ClassifierDLApproach(AnnotatorApproach):
+
+    lr = Param(Params._dummy(), "lr", "Learning Rate", TypeConverters.toFloat)
+
+    batchSize = Param(Params._dummy(), "batchSize", "Batch size", TypeConverters.toInt)
+
+    dropout = Param(Params._dummy(), "dropout", "Dropout coefficient", TypeConverters.toFloat)
+
+    maxEpochs = Param(Params._dummy(), "maxEpochs", "Maximum number of epochs to train", TypeConverters.toInt)
+
+    configProtoBytes = Param(Params._dummy(), "configProtoBytes", "ConfigProto from tensorflow, serialized into byte array. Get with config_proto.SerializeToString()", TypeConverters.toListString)
+
+    validationSplit = Param(Params._dummy(), "validationSplit", "Choose the proportion of training dataset to be validated against the model on each Epoch. The value should be between 0.0 and 1.0 and by default it is 0.0 and off.",
+                            TypeConverters.toFloat)
+
+    enableOutputLogs = Param(Params._dummy(), "enableOutputLogs",
+                             "Whether to use stdout in addition to Spark logs.",
+                             TypeConverters.toBoolean)
+
+    labelColumn = Param(Params._dummy(),
+                        "labelColumn",
+                        "Column with label per each token",
+                        typeConverter=TypeConverters.toString)
+
+    verbose = Param(Params._dummy(), "verbose", "Level of verbosity during training", TypeConverters.toInt)
+    randomSeed = Param(Params._dummy(), "randomSeed", "Random seed", TypeConverters.toInt)
+
+    def setVerbose(self, value):
+        return self._set(verbose=value)
+
+    def setRandomSeed(self, seed):
+        return self._set(randomSeed=seed)
+
+    def setLabelColumn(self, value):
+        return self._set(labelColumn=value)
+
+    def setConfigProtoBytes(self, b):
+        return self._set(configProtoBytes=b)
+
+    def setLr(self, v):
+        self._set(lr=v)
+        return self
+
+    def setBatchSize(self, v):
+        self._set(batchSize=v)
+        return self
+
+    def setDropout(self, v):
+        self._set(dropout=v)
+        return self
+
+    def setMaxEpochs(self, epochs):
+        return self._set(maxEpochs=epochs)
+
+    def _create_model(self, java_model):
+        return ClassifierDLModel(java_model=java_model)
+
+    def setValidationSplit(self, v):
+        self._set(validationSplit=v)
+        return self
+
+    def setEnableOutputLogs(self, value):
+        return self._set(enableOutputLogs=value)
+
+    @keyword_only
+    def __init__(self):
+        super(ClassifierDLApproach, self).__init__(classname="com.johnsnowlabs.nlp.annotators.classifier.dl.ClassifierDLApproach")
+        self._setDefault(
+            maxEpochs=30,
+            lr=float(0.005),
+            batchSize=64,
+            dropout=float(0.5),
+            enableOutputLogs=False
+        )
+
+
+class ClassifierDLModel(AnnotatorModel, HasStorageRef):
+    name = "ClassifierDLModel"
+
+    def __init__(self, classname="com.johnsnowlabs.nlp.annotators.classifier.dl.ClassifierDLModel", java_model=None):
+        super(ClassifierDLModel, self).__init__(
+            classname=classname,
+            java_model=java_model
+        )
+
+    configProtoBytes = Param(Params._dummy(), "configProtoBytes", "ConfigProto from tensorflow, serialized into byte array. Get with config_proto.SerializeToString()", TypeConverters.toListString)
+
+    def setConfigProtoBytes(self, b):
+        return self._set(configProtoBytes=b)
+
+    @staticmethod
+    def pretrained(name="classifier_sentiment", lang="en", remote_loc=None):
+        from sparknlp.pretrained import ResourceDownloader
+        return ResourceDownloader.downloadModel(ClassifierDLModel, name, lang, remote_loc)
